@@ -1,8 +1,8 @@
 package App::Netdisco::Util::SNMP;
 
 use Dancer qw/:syntax :script/;
-use App::Netdisco::Util::Device qw/get_device check_device_no/;
-use App::Netdisco::Util::Permission qw/check_acl/;
+use App::Netdisco::Util::Device 'get_device';
+use App::Netdisco::Util::Permission ':all';
 
 use SNMP::Info;
 use Try::Tiny;
@@ -81,7 +81,7 @@ sub _snmp_connect_generic {
   );
 
   # an override for bulkwalk
-  $snmp_args{BulkWalk} = 0 if check_device_no($device, 'bulkwalk_no');
+  $snmp_args{BulkWalk} = 0 if check_acl_no($device, 'bulkwalk_no');
 
   # further protect against buggy Net-SNMP, and disable bulkwalk
   if ($snmp_args{BulkWalk}
@@ -98,9 +98,9 @@ sub _snmp_connect_generic {
 
   # which SNMP versions to try and in what order
   my @versions =
-    ( check_device_no($device->ip, 'snmpforce_v3') ? (3)
-    : check_device_no($device->ip, 'snmpforce_v2') ? (2)
-    : check_device_no($device->ip, 'snmpforce_v1') ? (1)
+    ( check_acl_no($device->ip, 'snmpforce_v3') ? (3)
+    : check_acl_no($device->ip, 'snmpforce_v2') ? (2)
+    : check_acl_no($device->ip, 'snmpforce_v1') ? (1)
     : (reverse (1 .. (setting('snmpver') || 3))) );
 
   # use existing or new device class
@@ -136,9 +136,13 @@ sub _snmp_connect_generic {
 sub _try_connect {
   my ($device, $class, $comm, $mode, $snmp_args, $reclass) = @_;
   my %comm_args = _mk_info_commargs($comm);
-  my $debug_comm = ( $comm->{community}
-      ? $ENV{SHOW_COMMUNITY} ? $comm->{community} : '<hidden>'
-      : "v3user:$comm->{user}" );
+  my $debug_comm = '<hidden>';
+  if ($ENV{SHOW_COMMUNITY}) {
+    $debug_comm = ($comm->{community} ||
+      (sprintf 'v3:%s:%s/%s', ($comm->{user},
+                              ($comm->{auth}->{proto} || 'noAuth'),
+                              ($comm->{priv}->{proto} || 'noPriv'))) );
+  }
   my $info = undef;
 
   try {
@@ -293,14 +297,20 @@ sub _build_communities {
       $stanza->{tag} ||= $tag;
       ++$seen_tags->{ $stanza->{tag} };
       $stanza->{read} = 1 if !exists $stanza->{read};
+      $stanza->{no}   ||= [];
       $stanza->{only} ||= ['any'];
+      $stanza->{no}   = [$stanza->{no}] if ref '' eq ref $stanza->{no};
       $stanza->{only} = [$stanza->{only}] if ref '' eq ref $stanza->{only};
 
+      die "error: config: snmpv2 community in snmp_auth must be single item, not list\n"
+        if ref $stanza->{community};
+
       die "error: config: snmpv3 stanza in snmp_auth must have a tag\n"
         if not $stanza->{tag}
            and !exists $stanza->{community};
 
-      if ($stanza->{$mode} and check_acl($device->ip, $stanza->{only})) {
+      if ($stanza->{$mode} and check_acl_only($device, $stanza->{only})
+            and not check_acl_no($device, $stanza->{no})) {
           if ($device->in_storage and
             $stored_tag and $stored_tag eq $stanza->{tag}) {
               # last known-good by tag
